@@ -224,5 +224,10 @@ if(min(pars1) < 0 || pars1[1] <= pars1[2] || pars1[4] <= pars1[5] || -pars1[7] <
     loglik = loglik - logliknorm - lgamma(S + m + 1) + lgamma(S + 1) + lgamma(m + 1)
 }
 }
+s1 = sprintf('Parameters: %f %f %f %f %f %f %f, ',pars1[1],pars1[2],pars1[3],pars1[4],pars1[5],pars1[6],pars1[7])
+s2 = sprintf('Loglikelihood: %f',loglik)
+cat(s1,s2,"\n")
+flush.console()
+
 return(loglik)
 }   
