@@ -1,4 +1,4 @@
-dd_ML = function(brts,initparsopt=(ddmodel < 5) * c(0.5,0.1,2*length(brts)) + (ddmodel == 5) * c(0.5,0.1,2*length(brts),0.01),idparsopt = 1:length(initparsopt),idparsfix = (1:(3 + (ddmodel == 5)))[-idparsopt],parsfix = (ddmodel < 5) * c(0.2,0.1,2*length(brts))[-idparsopt] + (ddmodel == 5) * c(0.2,0.1,2*length(brts),0)[-idparsopt],res=10*(1+length(brts)),ddmodel=1,missnumspec=0,cond=TRUE, btorph = 1)
+dd_ML = function(brts,initparsopt=if(ddmodel < 5) {c(0.1+bd(as.numeric(brts))$r1/(1-bd(as.numeric(brts))$a),0.1,2*length(brts))} else {c(0.1+bd(as.numeric(brts))$r1/(1-bd(as.numeric(brts))$a),0.1,2*length(brts),0.01)},idparsopt = 1:length(initparsopt),idparsfix = (1:(3 + (ddmodel == 5)))[-idparsopt],parsfix = (ddmodel < 5) * c(0.2,0.1,2*length(brts))[-idparsopt] + (ddmodel == 5) * c(0.2,0.1,2*length(brts),0)[-idparsopt],res=10*(1+length(brts)),ddmodel=1,missnumspec=0,cond=TRUE, btorph = 1)
 {
 # brts = branching times (positive, from present to past)
 # - max(brts) = crown age
@@ -31,7 +31,9 @@ trparsopt = initparsopt/(1 + initparsopt)
 trparsfix = parsfix/(1 + parsfix)
 trparsfix[parsfix == Inf] = 1
 cat("Optimizing the likelihood - this may take a while.","\n")
-out = optimx2(trparsopt,dd_loglik_choosepar,hess=NULL,method = "Nelder-Mead",hessian = FALSE,control = list(maximize = TRUE,abstol = 1E-6,reltol = 1E-6,trace = 0,starttests = FALSE,kkt = FALSE),trparsfix = trparsfix,idparsopt = idparsopt,idparsfix = idparsfix,brts = brts,pars2 = c(res,ddmodel,cond,btorph),missnumspec = missnumspec)
+#out = optimx2(trparsopt,dd_loglik_choosepar,hess=NULL,method = "Nelder-Mead",hessian = FALSE,control = list(maximize = TRUE,abstol = 1E-6,reltol = 1E-6,trace = 0,starttests = FALSE,kkt = FALSE),trparsfix = trparsfix,idparsopt = idparsopt,idparsfix = idparsfix,brts = brts,pars2 = c(res,ddmodel,cond,btorph),missnumspec = missnumspec)
+out = optimx2(trparsopt,dd_loglik_choosepar,hess=NULL,method = "nlm",hessian = FALSE,control = list(maximize = TRUE,abstol = 1E-6,reltol = 1E-6,trace = 0,starttests = FALSE,kkt = FALSE),trparsfix = trparsfix,idparsopt = idparsopt,idparsfix = idparsfix,brts = brts,pars2 = c(res,ddmodel,cond,btorph),missnumspec = missnumspec)
+if(out$conv > 0) {cat("Optimization has not converged. Try again with different starting values.\n")} else {
 MLtrpars = unlist(out$par)
 MLpars = MLtrpars/(1-MLtrpars)
 out$par = list(MLpars)
@@ -41,9 +43,10 @@ MLpars1[idparsopt] = MLpars
 if(length(idparsfix) != 0) { MLpars1[idparsfix] = parsfix }
 s1 = sprintf('Maximum likelihood parameter estimates: lambda: %f, mu: %f, K: %f',MLpars1[1],MLpars1[2],MLpars1[3])
 if(ddmodel == 5) {s1 = sprintf('%s, r: %f',s1,MLpars1[4])}
-s2 = sprintf('Maxmimum loglikelihood: %f',out$fvalues)
+s2 = sprintf('Maximum loglikelihood: %f',out$fvalues)
 cat("\n",s1,"\n",s2,"\n")
 invisible(out)
 }
 }
+}
 }
\ No newline at end of file
