@@ -4,8 +4,15 @@ lx = length(x)
 la = pars[1]
 mu = pars[2]
 K = pars[3]
-kk = pars[4]
-ddep = pars[5]
+if(length(pars) < 6)
+{
+   kk = pars[4]
+   ddep = pars[5]
+} else {
+   r = pars[4]
+   kk = pars[5]
+   ddep = pars[6]
+}
 
 nn = -1:(lx+2*kk)
 lnn = length(nn)
@@ -30,7 +37,11 @@ if(ddep == 4)
     lavec = la * rep(1,lnn)
     muvec = mu * (nn + 1)^(log(la/mu)/log(K+1))
 }
-
+if(ddep == 5)
+{ 
+    lavec = pmax(rep(0,lnn),la - 1/(r+1)*(la-mu)/K * nn)
+    muvec = muvec = mu + r/(r+1)*(la-mu)/K * nn
+}
 xx = c(0,x,0)
 
 dx = lavec[(2:(lx+1))+kk-1] * nn[(2:(lx+1))+2*kk-1] * xx[(2:(lx+1))-1] + muvec[(2:(lx+1))+kk+1] * nn[(2:(lx+1))+1] * xx[(2:(lx+1))+1] - (lavec[(2:(lx+1))+kk] + muvec[(2:(lx+1))+kk]) * nn[(2:(lx+1))+kk] * xx[2:(lx+1)]
